# 字符类型检测

* [ctype_alnum - 做字母和数字字符检测](#ctypealnum)
* [ctype_alpha - 做纯字符检测](#ctypealpha)
* [ctype_cntrl - 做控制字符检测](#ctypecntrl)
* [ctype_digit - 做纯数字检测](#ctypedigit)
* [ctype_graph - 做可打印字符串检测，空格除外](#ctypegraph)
* [ctype_lower - 做小写字符检测](#ctypelower)
* [ctype_print - 做可打印字符检测](#ctypeprint)
* [ctype_punct - 检测可打印的字符是不是不包含空白、数字和字母](#ctypepunct)
* [ctype_space - 做空白字符检测](#ctypespace)
* [ctype_upper - 做大写字母检测](#ctypeupper)
* [ctype_xdigit - 检测字符串是否只包含十六进制字符](#ctypexdigit)

## ctype_alnum

```php
<?php

var_dump(ctype_alnum('AbCd1zyZ9')); // bool(true)
var_dump(ctype_alnum('foo!#$bar')); // bool(false)

```

## ctype_alpha

```php
<?php

var_dump(ctype_alpha('KjgWZC')); // bool(true)
var_dump(ctype_alpha('arf12'));  // bool(false)

```

## ctype_cntrl

```php
<?php

var_dump(ctype_cntrl("\n\r\t")); // bool(true)
var_dump(ctype_cntrl('\n\r\t')); // bool(false)
var_dump(ctype_cntrl('arf12'));  // bool(false)

```

## ctype_digit

```php
<?php

var_dump(ctype_digit('1820.20')); // bool(false)
var_dump(ctype_digit('10002'));   // bool(true)
var_dump(ctype_digit('wsl!12'));  // bool(false)

```

## ctype_graph

```php
<?php

var_dump(ctype_graph("asdf\n\r\t")); // bool(false)
var_dump(ctype_graph('arf 12'));     // bool(false)
var_dump(ctype_graph('LKA#@%.54'));  // bool(true)

```

## ctype_lower

```php
<?php

var_dump(ctype_lower('aac123'));  // bool(false)
var_dump(ctype_lower('qiutoas')); // bool(true)
var_dump(ctype_lower('QASsdks')); // bool(false)

```

## ctype_print

```php
<?php

var_dump(ctype_print("asdf\n\r\t")); // bool(false)
var_dump(ctype_print('arf 12'));     // bool(true)
var_dump(ctype_print('LKA#@%.54'));  // bool(true)

```

## ctype_punct

```php
<?php

var_dump(ctype_punct('ABasdk!@!$#')); // bool(false)
var_dump(ctype_punct('!@ # $'));      // bool(false)
var_dump(ctype_punct('*&$()'));       // bool(true)

```

## ctype_space

```php
<?php

var_dump(ctype_space("\n\r\t ")); // bool(true)
var_dump(ctype_space("\narf12")); // bool(false)
var_dump(ctype_space('\n\r\t'));  // bool(false)

```

## ctype_upper

```php
<?php

var_dump(ctype_upper('AKLWC139')); // bool(false)
var_dump(ctype_upper('LMNSDO'));   // bool(true)
var_dump(ctype_upper('akwSKWsm')); // bool(false)

```

## ctype_xdigit

```php
<?php

var_dump(ctype_xdigit('AB10BC99')); // bool(true)
var_dump(ctype_xdigit('AR1012'));   // bool(false)
var_dump(ctype_xdigit('ab12bc99')); // bool(true)

```

