# 运算符优先级

运算符优先级指定了两个表达式绑定得有多紧密。如果运算符优先级相同，那运算符的结合方向决定了该如何运算。没有结合的相同优先级的运算符不能连在一起使用。括号的使用，哪怕在不是必要的场合下，通过括号的配对来明确标明运算顺序，而非靠运算符优先级和结合性来决定，通常能够增加代码的可读性。下表按照优先级从高到低列出了运算符。同一行中的运算符具有相同优先级，此时它们的结合方向决定求值顺序。

| 结合方向 |                          运算符                          |
| :------: | :------------------------------------------------------: |
|    无    |                        clone new                         |
|    左    |                            [                             |
|    右    |                            **                            |
|    右    | ++ -- ~ (int) (float) (string) (array) (object) (bool) @ |
|    无    |                        instanceof                        |
|    右    |                            !                             |
|    左    |                          * / %                           |
|    左    |                          + - .                           |
|    左    |                          << >>                           |
|    无    |                        < <= > >=                         |
|    无    |                   == != <> === !== <=>                   |
|    左    |                            &                             |
|    左    |                            ^                             |
|    左    |                          &#124;                          |
|    左    |                            &&                            |
|    左    |                       &#124;&#124;                       |
|    左    |                            ??                            |
|    左    |                            ?:                            |
|    右    |   = += -= \*= /= %= \*\*= .= &= &#124;= ^= <<= >>= ??=   |
|    左    |                           and                            |
|    左    |                           xor                            |
|    左    |                            or                            |

算数运算符是左联的。

```php
<?php

$foo = 3 * 3 % 5;
var_dump($foo); // int(4)

```

赋值运算符是右联的。

```php
<?php

$foo = 1;
$bar = 2;
$foo = $bar += 3;
var_dump($foo); // int(5)
var_dump($bar); // int(5)

```

递增运算符优先级高于算数运算符和赋值运算符。

```php
<?php

$foo = 1;
$bar = $foo + $foo++;
var_dump($bar); // int(3)

```

