# 输出缓冲控制

* [flush - 刷新输出缓冲](#flush)
* [ob_clean - 清空输出缓冲区](#obclean)
* [ob_end_clean - 清空输出缓冲区并关闭输出缓冲](#obendclean)
* [ob_end_flush - 冲刷出输出缓冲区内容并关闭缓冲](#obendflush)
* [ob_flush - 冲刷出输出缓冲区中的内容](#obflush)
* [ob_get_clean - 得到当前输出缓冲区的内容并删除当前输出输出缓冲](#obgetclean)
* [ob_get_contents - 返回当前输出缓冲区的内容](#obgetcontents)
* [ob_get_flush - 冲刷出缓冲区内容，以字符串形式返回内容，并关闭输出缓冲区](#obgetflush)
* [ob_get_length - 返回输出缓冲区内容的长度](#obgetlength)
* [ob_get_level - 返回输出缓冲机制的嵌套级别](#obgetlevel)
* [ob_get_status - 得到所有输出缓冲区的状态](#obgetstatus)
* [ob_gzhandler - 在 ob_start 中使用的用来压缩输出缓冲区中内容的回调函数](#obgzhandler)
* [ob_implicit_flush - 打开 / 关闭绝对刷送](#obimplicitflush)
* [ob_list_handlers - 列出所有使用中的输出处理程序](#oblisthandlers)
* [ob_start - 打开输出控制缓冲](#obstart)
* [output_add_rewrite_var - 添加 URL 重写器的值](#outputaddrewritevar)
* [output_reset_rewrite_vars - 重设 URL 重写器的值](#outputresetrewritevars)

## flush

```php
<?php

echo 'Loading...';
flush();
sleep(2);
// Loading...

```

## ob_clean

```php
<?php

ob_start();
echo 'Loading...';
ob_clean();

```

## ob_end_clean

```php
<?php

ob_start();
echo 'Loading...';
ob_end_clean();

```

## ob_end_flush

```php
<?php

ob_start();
echo 'Loading...';
ob_end_flush();
// Loading...

```

## ob_flush

```php
<?php

ob_start();
echo 'Loading...';
ob_flush();
// Loading...

```

## ob_get_clean

```php
<?php

ob_start();
echo 'Loading...';
var_dump(ob_get_clean()); // string(10) "Loading..."

```

## ob_get_contents

```php
<?php

ob_start();
echo 'Loading...';
var_dump(ob_get_contents()); // string(10) "Loading..."
// Loading...

```

## ob_get_flush

```php
<?php

ob_start();
echo 'Loading...';
var_dump(ob_get_flush()); // string(10) "Loading..."
// Loading...

```

## ob_get_length

```php
<?php

ob_start();
echo 'Loading...';
var_dump(ob_get_length()); // int(10)
// Loading...

```

## ob_get_level

```php
<?php

ob_start();
echo 'Loading...';
var_dump(ob_get_level()); // int(1)
// Loading...

```

## ob_get_status

```php
<?php

ob_start();
echo 'Loading...';
var_dump(ob_get_status());
// Loading...

```

## ob_gzhandler

```php
<?php

ob_start('ob_gzhandler');

```

## ob_implicit_flush

```php
<?php

ob_implicit_flush();
ob_implicit_flush(true);
ob_implicit_flush(false);

```

## ob_list_handlers

```php
<?php

ob_start();
var_dump(ob_list_handlers()); // array(1) { [0]=> string(22) "default output handler" }

```

## ob_start

```php
<?php

var_dump(ob_start());               // bool(true)
var_dump(ob_start('ob_gzhandler')); // bool(true)

```

## output_add_rewrite_var

```php
<?php

var_dump(output_add_rewrite_var('foo', 'bar')); // bool(true)
var_dump('<form action="example.php"></form>'); // string(34) "<form action="example.php"><input type="hidden" name="foo" value="bar" /></form>"

```

## output_reset_rewrite_vars

```php
<?php

var_dump(output_add_rewrite_var('foo', 'bar')); // bool(true)
var_dump(output_reset_rewrite_vars());          // bool(true)
var_dump('<form action="example.php"></form>'); // string(34) "<form action="example.php"></form>"

```

