# 生成器总览

生成器提供了一种更容易的方法来实现简单的对象迭代，相比较定义类实现 `Iterator` 接口的方式，性能开销和复杂性大大降低。生成器允许你在 `foreach` 代码块中写代码来迭代一组数据而不需要在内存中创建一个数组，那会使你的内存达到上限，或者会占据可观的处理时间。相反，你可以写一个生成器函数，就像一个普通的自定义函数一样，和普通函数只返回一次不同的是，生成器可以根据需要 `yield` 多次，以便生成需要迭代的值。当第一次调用生成器函数时，将返回内部 `Generator` 类的对象。此对象实现 `Iterator` 接口的方式与仅向前迭代器对象的方式非常相似，并提供可以调用以操纵生成器状态的方法，包括向其发送值和从中返回值。一个简单的例子就是使用生成器来重新实现 `range()` 函数。 标准的 `range()` 函数需要在内存中生成一个数组包含每一个在它范围内的值，然后返回该数组，结果就是会产生多个很大的数组。比如，调用 `range(0, 1000000) ` 将导致内存占用超过 100 MB 。做为一种替代方法，可以实现一个 `xrange()` 生成器, 只需要足够的内存来创建 `Iterator` 对象并在内部跟踪生成器的当前状态，这样只需要不到 1 KB 字节的内存。

```php
<?php

/**
 * alternative function for range().
 *
 * @param  int    $start
 * @param  int    $end
 * @param  int    $step
 * @return void
 */
function xrange(int $start, int $end, int $step = 1)
{
    for ($i = $start; $i < $end; $i += $step) {
        yield $i;
    }
}

$foo = range(1, 10, 2);
foreach ($foo as $value) {
    var_dump($value);
}
// int(1)
// int(3)
// int(5)
// int(7)
// int(9)

$foo = xrange(1, 10, 2);
foreach ($foo as $value) {
    var_dump($value);
}
// int(1)
// int(3)
// int(5)
// int(7)
// int(9)

```

